@@ -2,7 +2,6 @@
 
 #' randomGODB
 #' 
-#' @import GO.db
 #' @import minimalistGODB
 #' @import graphics
 #' @import stats
@@ -39,7 +38,7 @@
 randomGODB<-
   function(GOGOA3,verbose=TRUE) {
     GOGOA3R<-GOGOA3
-    DBstats(GOGOA3,"original",verbose)
+    DBstats(GOGOA3,"original","biological_process",verbose)
     ontologies<-names(GOGOA3$ontologies)
     for(ontology in ontologies) {
       t1<-sort(table(GOGOA3$ontologies[[ontology]][,"HGNC"]),decreasing=TRUE)
@@ -48,7 +47,7 @@ randomGODB<-
       if(!identical(t1,t2))
         stop("!identical(t1,t2)")
     }
-    DBstats(GOGOA3R,"randomized",verbose)
+    DBstats(GOGOA3R,"randomized","biological_process",verbose)
     compare2DB(GOGOA3,GOGOA3R,verbose)
     return(GOGOA3R)
   }
@@ -140,7 +139,12 @@ DBstats<-
         print("",quote=FALSE)
       }
     }
+    
+    print(c("DBG DBSTATS",names(DB)))
+    
+    
     if(verbose) {
+      print(c("DBG DBSTATS",names(DB)))
       print(sprintf("Dimensions of the %s ontology:",ontology),quote=FALSE)
       print(dim(DB$ontologies[[ontology]]),quote=FALSE)
     
@@ -261,7 +265,21 @@ sizeGOcats<-
 #' dir<-"/Users/barryzeeberg/personal/GODB_RDATA/goa_human/"
 #' load(sprintf("%s/%s",dir,"GOGOA3_goa_human.RData"))
 #' ontology<-"biological_process"
-#' t<-characterizeDB(GOGOA3,ontology,ngene=3,GO.db::GOBPCHILDREN,GO.db::GOBPANCESTOR,hitters="all")
+#' # t<-characterizeDB(GOGOA3,ontology,ngene=3,GO.db::GOBPCHILDREN,GO.db::GOBPANCESTOR,hitters="all")
+#' 
+#' if (requireNamespace("GO.db", quietly = TRUE)) {
+#'  ch<-GO.db::GOBPCHILDREN
+#' } else {
+#'  stop("Install 'GO.db' from BioConductor to use this function.", call. = FALSE)
+#' }
+#' 
+#' if (requireNamespace("GO.db", quietly = TRUE)) {
+#'  GO.db::GOBPANCESTOR
+#' } else {
+#'  stop("Install 'GO.db' from BioConductor to use this function.", call. = FALSE)
+#' }
+#' 
+#' t<-characterizeDB(GOGOA3,ontology,ngene=3,ch,an,hitters="all")
 #' }
 #' 
 #' @return returns the sorted number of GO category sizes, and also has side effect of printing out some information
@@ -383,8 +401,23 @@ mapPerGene<-
 #' # or you can retrieve it from https://github.com/barryzee/GO/databases
 #' dir<-"/Users/barryzeeberg/personal/GODB_RDATA/goa_human/"
 #' load(sprintf("%s/%s",dir,"GOGOA3_goa_human.RData"))
-#' hitters(GOGOA3,ontology="biological_process",hitters="all",
-#'  5,GO.db::GOBPCHILDREN,GO.db::GOBPANCESTOR)
+#' 
+#' # hitters(GOGOA3,ontology="biological_process",hitters="all",
+#'  # 5,GO.db::GOBPCHILDREN,GO.db::GOBPANCESTOR)
+#'  
+#' if (requireNamespace("GO.db", quietly = TRUE)) {
+#'  ch<-GO.db::GOBPCHILDREN
+#' } else {
+#'  stop("Install 'GO.db' from BioConductor to use this function.", call. = FALSE)
+#' }
+#' 
+#' if (requireNamespace("GO.db", quietly = TRUE)) {
+#'  an<-GO.db::GOBPANCESTOR
+#' } else {
+#'  stop("Install 'GO.db' from BioConductor to use this function.", call. = FALSE)
+#' }
+#' 
+#' hitters(GOGOA3,ontology="biological_process",hitters="all", 5,Gch,an)
 #' }
 #' 
 #' @return returns no values, but has side effect of printing out some information
@@ -474,7 +507,21 @@ hitters<-
 #' load(sprintf("%s/%s",dir,"GOGOA3_goa_human.RData"))
 #' ontology<-"biological_process"
 #' genes<-c("CDC45","CELF2")
-#' fractAncest(genes,GOGOA3,ontology,GO.db::GOBPCHILDREN,GO.db::GOBPANCESTOR)
+#' #fractAncest(genes,GOGOA3,ontology,GO.db::GOBPCHILDREN,GO.db::GOBPANCESTOR)
+#' 
+#' if (requireNamespace("GO.db", quietly = TRUE)) {
+#'  ch<-GO.db::GOBPCHILDREN
+#' } else {
+#'  stop("Install 'GO.db' from BioConductor to use this function.", call. = FALSE)
+#' }
+#' 
+#' if (requireNamespace("GO.db", quietly = TRUE)) {
+#'  an<-GO.db::GOBPANCESTOR
+#' } else {
+#'  stop("Install 'GO.db' from BioConductor to use this function.", call. = FALSE)
+#' }
+#' 
+#' fractAncest(genes,GOGOA3,ontology,ch,an)
 #' }
 #'
 #' @return returns no values, but has side effect of printing out some results
@@ -533,7 +580,15 @@ fractAncest<-
 #' @param GOBPCHILDREN GO.db dataset
 #' 
 #' @examples
-#' BP_LEAF<-leafList(GO.db::GOBPCHILDREN)
+#' # BP_LEAF<-leafList(GO.db::GOBPCHILDREN
+#' 
+#' if (requireNamespace("GO.db", quietly = TRUE)) {
+#'  ch<-GO.db::GOBPCHILDREN
+#' } else {
+#'  stop("Install 'GO.db' from BioConductor to use this function.", call. = FALSE)
+#' }
+#' 
+#' BP_LEAF<-leafList(ch)
 #' 
 #' @return returns a list of leaf nodes
 #' 
